# Posty

![posty](https://socialify.git.ci/not-so-cool-anymore/posty/image?description=1&descriptionEditable=A%20basic%20command%20line%20URL%20shortener%20wrapped%20around%20the%20Tinyurl%20API.&font=KoHo&language=1&owner=1&pattern=Circuit%20Board&stargazers=1&theme=Dark)

---

## Installation
You can install it from PyPi with `pip install i-posty` or locally with `pip install .`.

## Usage
You can run Posty by writing `posty` on the command line. It will copy the content of your clipboard, validate if it is a valid URL
with Regex, shorten it and copy it to the clipboard again.

## Requirements
 * Clipboard - `pip install clipboard`
